;
; ------------------------------------------------------------------------------------------
;
;   PureDemo  - Getting Started with PureBasic and code libraries
;             - Public Domain by Bob Houle (blueb)
;             - March 08, 2004 ver 1.30
;
;    (c) 2004 - Fantaisie Software
;
; About PureDemo - New users needed a small program to help
;   them navigate a new language, new methods, etc. so I decided
;   to create a small application to see if I sould help.
;   I could have made it more complicated by compiling the samples
;   for the new user, but decided to leave that to them, If they only
;   have the demo, they couldn't compile all the samples in any case.
;   I've included a few samples in the "User Snippets Folder" from the PB forum. These were
;   chosen (and possibly modified) for their simplicity. I've tried to include
;   the contributor's name wherever possible. If you find some problems
;   please let me know. Thank you for your generosity!!
;
;   Note: You can use PureDemo as a sort of 'Code Librarian' to keep
;   all your source code and collected sample is one location (the
;   'User Snippets' folder?? Possibly transfer your favorites here from CodeArchiv from Andre
;
;   This source file demonstrates pref files and how to use panelgadgets 
; -------------------------------------------------------------------------------------------
;
; Constants
; -----------------
#WindowWidth  = 390
#WindowHeight = 350
#Version      = "Version 1.30" ; March 08, 2004

#PBDemo       = 900  ; Panel(Tab) Events
#StartDemo    = 901
#SnippetsDemo = 902

; Trigger to determine which PanelGadget is active
; ------------------------------------------------
Global TabTrigger.l

; Values for "User.pref" preference file
; ---------------------------------------
Global PBDemoDir.s
Global PBStartDir.s
Global PBLocation.s
Global PBSnippets.s
;=============================================================
;Find out the user's drive information
Procedure.s CurrentDir() 
    sDir.s = " "                                   ; Local variable 
    BuffSize.l = GetCurrentDirectory_(2,@sDir)     ; Guaranteed to fail, but the return value is the required buffer length... 
    If BuffSize = 0                                ; ...unless there was a REAL error (couldn't read dir, etc) 
       ProcedureReturn ""                        ; Couldn't get the directory path 
    EndIf 
    sDir = Space(BuffSize)                         ; So now we can re-call it with the correct size: 
    BuffSize = GetCurrentDirectory_(BuffSize,@sDir); And sDir contains the current full path (minus "\" at the end) 
    If BuffSize: ProcedureReturn sDir: Else: ProcedureReturn "": EndIf 
EndProcedure
DriveLetter.s =  Left(CurrentDir(), 3) ; see above
;==================================================================

; Read the user preferences. If not... we'll create a new file.
If OpenPreferences("PureDemo.pref")
    PBLocation = ReadPreferenceString ("ProgLocation", PBLocation)
    PBDemoDir  = ReadPreferenceString ("DemoDirectory", PBDemoDir)
    PBStartDir = ReadPreferenceString ("StarterDirectory", PBStartDir)
    PBSnippets = ReadPreferenceString ("SnippetsDirectory", PBSnippets)
   ClosePreferences()
Else
  ;Likely location for PureBasic... default information
  PBDemoDir = DriveLetter +"PureBasic\Examples\Sources\"
  PBStartDir = DriveLetter + "PureBasic\PureDemo\Starter\"
  PBLocation = DriveLetter + "PureBasic\"
  PBSnippets = DriveLetter + "PureBasic\PureDemo\UserSnippets\"
  ; Create Preference File
  MessageRequester("PureDemo Program", "Note, for your convienience the PureDemo source code is " + Chr(10) + "located in the 'User Snippets' folder. Also, since I cannot find"+ Chr(10) + "your PureDemo.pref file, let's build a new 'pref' file...", 0)
  Title$ = "Automated next time you use PureDemo.exe"
  PBLocation = InputRequester(Title$, "Enter location of PureBasic.EXE", PBLocation)
  PBStartDir = InputRequester(Title$, "Enter desired location of Starter Folder", PBStartDir)
  PBDemoDir = InputRequester(Title$, "Enter location of PureBasic's Demo Directory", PBDemoDir)
  PBSnippets = InputRequester(Title$, "Enter desired location of UserSnippets Folder", PBSnippets) 
  
    CreatePreferences("PureDemo.pref")
    WritePreferenceString ("ProgLocation", PBLocation)
    WritePreferenceString ("DemoDirectory", PBDemoDir)
    WritePreferenceString ("StarterDirectory", PBStartDir)
    WritePreferenceString ("SnippetsDirectory", PBSnippets)
    
  ClosePreferences()
EndIf

;Declaration Area
; ---------------
Declare GetFiles()
Declare RunExe()
Declare ViewFiles() 
Declare GetStarterFiles()
Declare RunStarterExe()
Declare ViewStarterFiles()
Declare GetUserFiles() 
Declare RunUserExe()
Declare ViewUserFiles() 

; ================================================================================
Global hWnd.l

hWnd = OpenWindow(0, 100, 120, #WindowWidth, #WindowHeight, #PB_Window_WindowCentered |#PB_Window_MinimizeGadget, "PureBasic Librarian")
 If CreateGadgetList(hWnd)
    Top = 10
    GadgetHeight = 24

    hFrame = Frame3DGadget(13, 10, Top, 370, 290, " Select A Program: ", 0) : Top + 20
    StringGadget(0,  20, Top, 200, GadgetHeight, "", #PB_String_ReadOnly)
    ButtonGadget(1, 223, Top,  72, GadgetHeight, "Run Code")
    ButtonGadget(2, 295, Top,  72, GadgetHeight, "View Code")  : Top+35
    ;Disable Run/View buttons
    DisableGadget(1,1) 
    DisableGadget(2,1)
    
    PanelGadget(3, 20, Top, #WindowWidth-40, #WindowHeight-Top-60)
     
      AddGadgetItem(3, 0, " PB Demos ")
        ListViewGadget(#PBDemo, 6, 10, 280, 180, #LBS_SORT | #LBS_NOINTEGRALHEIGHT | #LBS_HASSTRINGS)
       ;Get stuff into the Main ListView
        GetFiles()

      AddGadgetItem(3, 1, " Getting Started ")
         ListViewGadget(#StartDemo, 6, 10, 280, 180, #LBS_SORT | #LBS_NOINTEGRALHEIGHT | #LBS_HASSTRINGS)
       ;Get stuff into the Starter ListView
        GetStarterFiles()

      AddGadgetItem(3, 2, " User Snippets ")
         ListViewGadget(#SnippetsDemo, 6, 10, 280, 180, #LBS_SORT | #LBS_NOINTEGRALHEIGHT | #LBS_HASSTRINGS)
       ;Get stuff into the User Snippets ListView
        GetUserFiles()

      AddGadgetItem(3, 3, " Instructions ")
        instr.s =       "Click on the listbox item you wish to work with.  It will be placed in the selection box, where you can either Run Or View "
        instr = instr + "the selected sample file.   Select your file locations using the boxes below."
        TextGadget(5,  10, 5, 320, 180, instr)
        ; ---------------------------------------------------
        ;Get Starter directory
        TextGadget  (6, 10, 125, 300, 18, "Getting Started Files:")
        StringGadget(7, 10, 140, 295, 18, PBStartDir, #PB_String_ReadOnly)
        ButtonGadget(8, 310, 140, 30, 19, "...")
     
       ;Get Snippets directory
        TextGadget  (9, 10, 165, 300, 18, "User Snippet Files:")
        StringGadget(10, 10, 180, 295, 18, PBSnippets, #PB_String_ReadOnly)
        ButtonGadget(11, 310, 180, 30, 19, "...")
        
       ;Get PBDemo directory
        TextGadget  (12, 10, 85, 300, 18, "PureBasic Demo Files:")
        StringGadget(13, 10, 100, 295, 18, PBDemoDir, #PB_String_ReadOnly)
        ButtonGadget(14, 310, 100, 30, 19, "...")
        
       ;Get PureBasic Compiler directory
        TextGadget  (15, 10, 45, 300, 18, "PureBasic Compiler Location:")
        StringGadget(16, 10, 60, 295, 18, PBLocation, #PB_String_ReadOnly)
        ButtonGadget(17, 310, 60, 30, 19, "...")
    CloseGadgetList()
    
    TextGadget(18, 10, #WindowHeight-30, 170, 24, "PureBasic Beginner Demonstration")

    TextGadget(19, 180, #WindowHeight-30, 100, 24, #Version)

    ButtonGadget(20, #WindowWidth-95, #WindowHeight-35, 80, 24, "Quit")

    GadgetToolTip(0,"Choose an item from the listbox below")
    GadgetToolTip(1,"Executes the compiled program on the left")
    GadgetToolTip(2,"Opens the source code in PureBasic's editor")
    GadgetToolTip(#PBDemo,"Select an item to 'Run' or 'View' its source code")
    GadgetToolTip(#StartDemo,"Very basic sample files to get you started.")
    GadgetToolTip(#SnippetsDemo,"Add PB source files to this directory and build your own 'User Templates'")

  EndIf
  
; ====================== Windows Event Loop ======================== 
  Repeat
    EventID = WaitWindowEvent()
  
    
    If EventID = #PB_EventGadget

      Select EventGadgetID()
           
        Case 1  ; Play EXE
        
          Select TabTrigger
              Case 1
                RunExe()
              Case 2
                RunStarterExe()
              Case 3
                RunUserExe()
          EndSelect   
              
        Case 2  ; View Code
        
          Select TabTrigger
              Case 1
                ViewFiles()
              Case 2
                ViewStarterFiles()
              Case 3
                ViewUserFiles()
          EndSelect   

              
        Case 8 ; Find 'Getting Started' Dir...
            PBStartDir = PathRequester("Choose a path...",DriveLetter + "PureBasic\Starter")
            If PBStartDir
              SetGadgetText(7, PBStartDir) ; Place answer in the edit box
            EndIf

        Case 11 ; Find 'User Snippets' Dir...
            PBSnippets = PathRequester("Choose a path...",DriveLetter +"PureBasic\UserSnippets")
            If PBSnippets
              SetGadgetText(10, PBSnippets) ; Place answer in the edit box
            EndIf
             
        Case 14 ; Find 'PB Demo' Dir...
            PBDemoDir = PathRequester("Choose a path...",DriveLetter +"PureBasic\Examples\Sources")
            If PBDemoDir
              SetGadgetText(13, PBDemoDir) ; Place answer in the edit box
            EndIf
            
        Case 20 ; Quit...
          EventID = #PB_EventCloseWindow

        Case 17 ; Find 'Compiler.exe' Dir...
            PBLocation = PathRequester("Choose a path...",DriveLetter +"PureBasic")
            If PBLocation
              SetGadgetText(13, PBLocation) ; Place answer in the edit box
            EndIf

        Case 900  ; PB Demo Code
          TabTrigger = 1
          
          If EventType() = #PB_EventType_LeftClick 
          ;Enable Run/View buttons
          DisableGadget(1,0)  
          DisableGadget(2,0)           
          SetGadgetText(0, GetGadgetText(#PBDemo)) ; Place current item in the edit box
          EndIf
          
        Case 901  ; Starter Code
          TabTrigger = 2
          
          If EventType() = #PB_EventType_LeftClick 
          ;Enable Run/View buttons
          DisableGadget(1,0)  
          DisableGadget(2,0)           
          SetGadgetText(0, GetGadgetText(#StartDemo)) ; Place current item in the edit box
          EndIf
          
        Case 902  ; User Snippets Code
          TabTrigger = 3
          
          If EventType() = #PB_EventType_LeftClick 
          ;Enable Run/View buttons
          DisableGadget(1,0)  
          DisableGadget(2,0)           
          SetGadgetText(0, GetGadgetText(#SnippetsDemo)) ; Place current item in the edit box
          EndIf
          
  
      EndSelect

    EndIf
    

  Until EventID = #PB_EventCloseWindow


; Update the User preferences before closing program.
; --------------------------------------------------
If OpenPreferences("PureDemo.pref") 
     CreatePreferences("PureDemo.pref")
       WritePreferenceString ("ProgLocation", PBLocation)
       WritePreferenceString ("DemoDirectory", PBDemoDir)
       WritePreferenceString ("StarterDirectory", PBStartDir)
       WritePreferenceString ("SnippetsDirectory", PBSnippets)
     ClosePreferences()
EndIf

End ; Exit Program


; 
;                             Required Procedures And Routines
; 

; =============================
; PB Demo routines
; =============================
Procedure GetFiles()

        ClearGadgetItemList(#PBDemo)  ; Clear the ListView
        If ExamineDirectory(0, PBDemoDir, "*.pb") ; Find all the source files
          Repeat
            FileType = NextDirectoryEntry()
            If FileType
              FileName$ = DirectoryEntryName()
              If FileType = 2 ; Directory type
                FileName$ = "(DIR) " + FileName$  
              EndIf
              ;strip off the ".PB" file extension
              FileName$ = Left(FileName$, (Len(FileName$)-3))
              ; Sort...while adding to ListViewGadget
              SendMessage_( GadgetID(#PBDemo), #LB_ADDSTRING, 0, FileName$)
            EndIf
          Until FileType = 0 
        Else
          MessageRequester("Sorry - Error","Did NOT find a PureBasic file, please edit the 'PureDemo.pref' file",0)
          End
        EndIf

EndProcedure
; ==============================
Procedure RunExe()

 ans.s = GetGadgetText(0)
 ans = ans + ".exe"
 ans = PBDemoDir + ans
 Result.l = RunProgram(ans, "","", 0)
 If Result = 0
    MessageRequester("PureDemo", "Sorry, You'll have to compile the sample code first!", 0)
 EndIf
EndProcedure
; ==============================
Procedure ViewFiles()

 ans.s = GetGadgetText(0)
 ans = PBDemoDir + ans + ".pb" 
 prog.s = PBLocation +"purebasic.exe"
 Result.l = RunProgram( Chr(34)+ prog +Chr(34) , Chr(34)+ ans +Chr(34), "" ,0)

EndProcedure

; =============================
; Getting Started Routines
; =============================
Procedure GetStarterFiles()

        ClearGadgetItemList(#StartDemo)  ; Clear the ListView
        If ExamineDirectory(0, PBStartDir, "*.pb") ; Find all the source files
          Repeat
            FileType = NextDirectoryEntry()
            If FileType
              FileName$ = DirectoryEntryName()
              If FileType = 2 ; Directory type
                FileName$ = "(DIR) " + FileName$  
              EndIf
              ;strip off the ".PB" file extension
              FileName$ = Left(FileName$, (Len(FileName$)-3))
              ; Sort...while adding to ListViewGadget
              SendMessage_( GadgetID(#StartDemo), #LB_ADDSTRING, 0, FileName$)
            EndIf
          Until FileType = 0 
        Else
          MessageRequester("Error","Something went wrong!",0)
          End
        EndIf

EndProcedure
; ==============================
Procedure RunStarterExe()

 ans.s = GetGadgetText(0)
 ans = PBStartDir + ans + ".exe"
 Result.l = RunProgram(ans, "","", 0)
 If Result = 0
    MessageRequester("PureDemo", "Sorry, You'll have to compile the sample code first!", 0)
 EndIf
  
EndProcedure
; ==============================
Procedure ViewStarterFiles()

 ans.s = GetGadgetText(0)
 ans = PBStartDir + ans + ".pb" 
 prog.s = PBLocation +"purebasic.exe" 
 Result.l = RunProgram( Chr(34)+ prog +Chr(34) , Chr(34)+ ans +Chr(34), "" ,0)
 
EndProcedure

; =============================
; User Snippets Routines
; =============================
Procedure GetUserFiles()

        ClearGadgetItemList(#SnippetsDemo)  ; Clear the ListView
        If ExamineDirectory(0, PBSnippets, "*.pb") ; Find all the source files
          Repeat
            FileType = NextDirectoryEntry()
            If FileType
              FileName$ = DirectoryEntryName()
              If FileType = 2 ; Directory type
                FileName$ = "(DIR) " + FileName$  
              EndIf
              ;strip off the ".PB" file extension
              FileName$ = Left(FileName$, (Len(FileName$)-3))
              ; Sort...while adding to ListViewGadget
              SendMessage_( GadgetID(#SnippetsDemo), #LB_ADDSTRING, 0, FileName$)
            EndIf
          Until FileType = 0 
        Else
          MessageRequester("Error","Something went wrong!",0)
          End
        EndIf

EndProcedure
; ==============================
Procedure RunUserExe()

 ans.s = GetGadgetText(0)
 ans = PBSnippets + ans + ".exe"
 Result.l = RunProgram(ans, "","", 0)
 If Result = 0
    MessageRequester("PureDemo", "Sorry, You'll have to compile the sample code first!", 0)
 EndIf
  
EndProcedure
; ==============================
Procedure ViewUserFiles()

 ans.s = GetGadgetText(0)
 ans = PBSnippets + ans + ".pb" 
 prog.s = PBLocation +"purebasic.exe" 
 Result.l = RunProgram( Chr(34)+ prog +Chr(34) , Chr(34)+ ans +Chr(34), "" ,0)

EndProcedure
;================================

; 
;                                      End of Procedures
; 
; ExecutableFormat=Windows
; CursorPosition=74
; FirstLine=54
; EnableAsm
; EnableNT4
; UseIcon=C:\PUREBASIC\Logo.ico
; Executable=C:\PUREBASIC\BobDev\PureDemo\PureDemo.exe
; EOF